function VaR = finrisk_VaRpar(alpha_vec,distr,par_vec)
% FINRISK_VARPAR calculates the Value at Risk for parametric models 
% given the relevant distribution parameters
%  
% Syntax: VaR = FINRISK_VARPAR(alpha_vec,distr,par_vec) 
%
% Inputs:
%   alpha_vec - vector of significance levels (exceedance proabilities)
%   distr     - distribution type: 'n' normal distribution, 
%               'tstd'  standardized three-parameter t-distribution, 
%               't'     three parameter t-distribution
%               'st'    skewed t distribution
%               'ghstd' standardized gh distribution
%   par_vec   - vector of input parameters    
%
% See also: norminv, tinv, VaRpar_data   
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if size(alpha_vec,2)>1
    alpha_vec = alpha_vec';
end

switch distr
    case 'n'
        if length(par_vec)~=2
            error('Normal-VaR requires two parameters.');
        end
        muL = par_vec(1);
        sigmaL = par_vec(2);
        VaR(:,1) = muL + sigmaL * norminv(1-alpha_vec,0,1);
    case 'tstd'
        if length(par_vec)~=3
            error('tstd-VaR requires three parameters');
        end
        nuL = par_vec(1);
        muL = par_vec(2);
        sigmaL = par_vec(3);
        VaR(:,1) = muL + sigmaL * sqrt((nuL-2)/nuL) * tinv(1-alpha_vec,nuL);
    case 't'
        if length(par_vec)~=3
            error('t-VaR requires three parameters.');
        end
        nuL = par_vec(1);
        muL = par_vec(2);
        sigmaL = par_vec(3);
        VaR(:,1) = muL + sigmaL * tinv(1-alpha_vec,nuL);
    case 'st'
        if length(par_vec)~=4
            error('st-VaR requires four parameters.');
        end
        nuL = par_vec(1);
        lamL = par_vec(2);
        muL = par_vec(3);
        sigmaL = par_vec(4);
        VaR(:,1) = st_inv(1-alpha_vec,nuL,lamL,muL,sigmaL);
    case 'ghstd'
        if length(par_vec)~=4
            error('st-VaR requires four parameters.');
        end
        gL = par_vec(1);
        hL = par_vec(2);
        muL = par_vec(3);
        sigmaL = par_vec(4);
        VaR(:,1) = ghstd_inv(1-alpha_vec,gL,hL,muL,sigmaL);        
    otherwise
        error('unkown distribution');
end

end
