function [VaR,par_vec] = finrisk_VaRpar_data(alpha_vec,distr,l_vec,estmeth,estls)
% FINRISK_VARPAR_DATA calculates the Value at Risk for parametric models  
% given a loss sample
%  
% Syntax: 
%   VaR = FINRISK_VARPAR_DATA(alpha_vec,distr,l_vec) 
%   VaR = FINRISK_VARPAR_DATA(alpha_vec,distr,l_vec,estmeth) 
%   [VaR,par_vec] = FINRISK_VARPAR_DATA(...) 
%
% Inputs:
%   alpha_vec - vector of signifiance levels (exceedance probabilities)
%   distr     - distribution type: 
%               'n' normal distribution,
%               't' three parameter t-distribution
%               'st' skewed t distribution
%               'ghstd' standardized gh distribution
%   l_vec     - vector of input-data
%   estmeth   - estimation method for the distribution. Choose 'mom' for 
%               moment-based estimation and 'mle' for maximum 
%               likelihood estimation.
%
% Outputs:
%   VaR    - vector of VaR estimtates
%   par_vec    - estimated distribution parameters
% 
% See also: finrisk_VaRpar, finrisk_est_t  
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% revision: 1.1      date: 2015/09/09

if nargin < 4
    estmeth = [];
end

if nargin < 5
    estls = true;
end

switch distr
    case 'n'
        if estls
            muL = mean(l_vec);
            sigL = std(l_vec);
        else
            muL = 0;
            sigL = 1;            
        end
        par_vec = [muL sigL];
    case 't'
        [muL,~,nuL,sigL] = finrisk_est_t(l_vec,estmeth,true);
        par_vec = [nuL,muL,sigL];
    case 'tstd'        
        [muL,sigL,nuL] = finrisk_est_tstd(l_vec,estls);
        par_vec = [nuL,muL,sigL];        
    case 'st'        
        [muL,sigL,nuL,lamL] = finrisk_est_st(l_vec,estls);
        par_vec = [nuL,lamL,muL,sigL];
    case 'ghstd'
        [muL,sigL,gL,hL] = finrisk_est_gh(l_vec,estmeth,estls);
        par_vec = [gL,hL,muL,sigL];        
    otherwise
        error('unkown distribution');
end

VaR = finrisk_VaRpar(alpha_vec,distr,par_vec);
end