function ESvec = finrisk_ESpar(alpha_vec,distr,par_vec)
% FINRISK_ESPAR calculates the Expected Shortfall based on a parametric 
%   model given the relevant distribution parameters
%  
% Syntax: ESvec = FINRISK_ESPAR(alpha_vec,distr,par_vec) 
%
% Inputs:
%   alpha_vec - vector of significance levels
%   distr     - distribution type: 'n' normal distribution, 
%               'tstd' standardized three-parameter t-distribution, 
%               't' three parameter t-distribution
%               'st' skewed t distribution
%               'ghstd' standardized g-and-h distribution
%   par_vec   - vector of input parameters    
%
% See also: finrisk_ESpar_data   
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/09/09

if size(alpha_vec,2)>1
    alpha_vec = alpha_vec';
end

    switch distr
       case 'n'
            if length(par_vec)~=2
                error('Normal-VaR requires two parameters.');
            end
            muL = par_vec(1);
            sigmaL = par_vec(2);
            lambda = normpdf(norminv(1-alpha_vec,0,1),0,1)./alpha_vec;            
            ESvec(:,1) = muL + sigmaL * lambda;
       case 'tstd'
            if length(par_vec)~=3
                error('tstd-VaR requires three parameters');
            end
            nuL = par_vec(1);
            muL = par_vec(2);
            sigmaL = par_vec(3);
            qt = tinv(1-alpha_vec,nuL);
            lamt = tpdf(qt,nuL)./alpha_vec .* (nuL+qt.^2)./(nuL-1);
            lamstd  = sqrt((nuL-2)/nuL) * lamt;
            ESvec(:,1) = muL + sigmaL * lamstd;
       case 't'
            if length(par_vec)~=3
                error('t-VaR requires three parameters.');
            end
            nuL = par_vec(1);
            muL = par_vec(2);
            sigmaL = par_vec(3);
            qt = tinv(1-alpha_vec,nuL);
            lam = tpdf(qt,nuL)./alpha_vec .* (nuL+qt.^2)./(nuL-1);
            ESvec(:,1) = muL + sigmaL * lam;
        case 'st'
            if length(par_vec)~=4
                error('st-VaR requires four parameters.');
            end
            nuL = par_vec(1);
            lamL = par_vec(2);
            muL = par_vec(3);
            sigmaL = par_vec(4);
            ESvec(:,1) = st_ulambda(1-alpha_vec,nuL,lamL,muL,sigmaL);
        case 'ghstd'
            if length(par_vec)~=4
                error('st-VaR requires four parameters.');
            end
            gL = par_vec(1);
            hL = par_vec(2);
            muL = par_vec(3);
            sigmaL = par_vec(4);
            ESvec(:,1) = ghstd_ulambda(1-alpha_vec,gL,hL,muL,sigmaL);        
       otherwise
            error('unkown distribution');
    end
end
