function [ESvec,par_vec] = finrisk_ESpar_data(alpha_vec,distr,l_vec,estmeth,estls)
% FINRISK_ESPAR_DATA calculates the Expected shortfall (ES) assuming a parametric 
%   distribution given a sample from this distribution
%  
% Syntax: 
%   ESvec = FINRISK_ESPAR_DATA(alpha_vec,distr,l_vec) 
%   ESvec = FINRISK_ESPAR_DATA(alpha_vec,distr,l_vec,estmeth,estls) 
%   [ESvec,par_vec] = FINRISK_ESPAR_DATA(...) 
%
% Inputs:
%   alpha_vec - vector of significance levels
%   distr     - distribution type: 'n' normal distribution, 
%                't' three parameter t-distribution
%   l_vec     - vector of input-data
%   estmeth   - estimation method for t-distribution. Choose 'mom' for 
%                moment-based estimation and 'mle' for maximum 
%                likelihood estimation.
%   estls     - include location scale model (std: true);
%
% Outputs:
%   ESvec     - vector of the corresponding ES values 
%   par_vec   - estimated distribution parameters
% 
% See also: finrisk_ESpar, finrisk_est_t  
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/09/09

    if nargin < 4
        estmeth = [];
    end

    if nargin < 5
        estls = true;
    end
    
    switch distr
        case 'n'
             if estls
                 muL = mean(l_vec);
                 sigL = std(l_vec);
             else
                 muL = 0;
                 sigL = 1;
             end
             par_vec = [muL sigL];
        case 't'
            [muL,~,nuL,sigL] = finrisk_est_t(l_vec,estmeth,estls);
            par_vec = [nuL,muL,sigL];
        case 'tstd'
            [muL,sigL,nuL] = finrisk_est_tstd(l_vec,estls);
            par_vec = [nuL,muL,sigL];
        case 'st'
            [muL,sigL,nuL,lamL] = finrisk_est_st(l_vec,estls);
            par_vec = [nuL,lamL,muL,sigL];
        case 'ghstd'
            [muL,sigL,gL,hL] = finrisk_est_gh(l_vec,estmeth,estls);
            par_vec = [gL,hL,muL,sigL];        
        otherwise
            error('unkown distribution');
    end

    ESvec = finrisk_ESpar(alpha_vec,distr,par_vec);
end