function [ESmat,sigvec,VaRmat,par_mat] = finrisk_dynESgarch(alpha_in,method,pre_sample,sample,T_est,t_update,inc_mean,show_info)
% FINRISK_DYNESGARCH calculates a series of dynamic Expected Shortfall (ES)
%       estimates using a GARCH model
%  
% Syntax: 
%   ESvec = FINRISK_DYNESGARCH(alpha_in,method,pre_sample)
%   ESvec = FINRISK_DYNESGARCH(alpha_in,method,pre_sample,sample,...
%                                        T_est,t_update,inc_mean,show_info)
%   [ESvec,sigvec,par_mat] = FINRISK_DYNESGARCH(...)
%
% Inputs:
%   alpha_in   - significance level/exceedance probability (vectors not
%                supported)
%   method     - ES-estimation method; must be in {'emp','n','pot'}
%   pre_sample - observations used for estimation only
%   sample     - observations for which forecasts are calculated and which
%                might be used for later estimations
%   T_est      - number of observation used for the rolling estimation 
%   t_update   - number of observations after which the forecast is updated
%   inc_mean   - include a mean constant in the model
%   show_info  - 'true' if information should be displayed (standard='false')
%
% Outputs:
%   ESvec   - vector of ES estimates
%   sigvec  - vector of volatility estimates
%   par_mat - matrix with estimated parameters 
%
% See also: finrisk_est_garch, finrisk_volgarch_par
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% revision: 1.1      date: 2014/10/16

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    sample = [];
end


if length(pre_sample)==length(sample) ... 
    && max(abs(pre_sample-sample))==0
   in_sample = true; 
else
   in_sample = false;
end

if nargin < 5
    T_est = 250;
end

if nargin < 6
    t_update = 1;
end

if nargin < 7
    inc_mean = true;
end

if nargin < 8
    show_info = true;
end

%if size(alpha_in,1) > 1
%    error('not implemented yet');
%end

if size(alpha_in,2) > 1
    alpha_in = alpha_in';
end
n_alpha = length(alpha_in);

t0 = length(pre_sample);
T_prog  = length(sample);

if T_prog < t_update
    T_prog = t_update; % only one forecast based on the presample
end

l_all = [pre_sample;sample];
if t0 < T_est
    error('presample must contain at least T_est observations.');
end

% see calculations at the end of the file for index constructions
ESmat = zeros(T_prog,n_alpha);
VaRmat = zeros(T_prog,n_alpha);
sigvec = zeros(T_prog,1);
c=0;
if show_info, fprintf('Estimating GARCH-ES %s #=: ',method);end
for t=0:t_update:T_prog-1
    c=c+1;
    if show_info, fprintf(' %d ',c); end
    ind_est_start = t0+(t+1)-T_est; % ex t=0: 1000 + 1 - 250 =  751;
    ind_est_end   = t0+(t+1)-1; % ex t=0: 1000 + 1 - 1   = 1000;
    est_sample_t  = l_all(ind_est_start:ind_est_end);
    i_start = t+1;
    i_end   = t+1+(t_update-1);
    
    if t0+i_end > length(l_all)
        i_end = length(l_all) - t0;
    end
    sample_t = l_all(t0+i_start:t0+i_end);
    
    % vola filter and forecast
    [par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4)] = finrisk_est_garch(est_sample_t,inc_mean);
    if in_sample        
        prog_sig_t = finrisk_volgarch_par(est_sample_t,sample_t,par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4),2);
    else
        [prog_sig_t,pre_sig_t] = finrisk_volgarch_par(est_sample_t,sample_t,par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4));
    end

    testneu_cond = true;
    if testneu_cond
        pre_sig_t = finrisk_volgarch_par(est_sample_t,est_sample_t,par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4),2);
    end

        
    % use filtered vola to estimate residuals
    z_sample_t = (est_sample_t-par_mat(c,4))./pre_sig_t;
    switch method
        case 'emp'
            ES_z = finrisk_ESemp(alpha_in,z_sample_t);
            if nargout > 2
                VaR_z = finrisk_VaRemp(alpha_in,z_sample_t);
            end
        case {'n';'tstd';'st';'ghstd'}
            estls = false;
            [ES_z,par_vec] = finrisk_ESpar_data(alpha_in,method,z_sample_t,[],estls);
            if nargout > 2
                VaR_z = finrisk_VaRpar(alpha_in,method,par_vec);
            end
        case 'pot'
            [ES_z,VaR_z] = finrisk_ESpot_data(alpha_in,z_sample_t);
        otherwise
            error('method not implemented');
    end
    sigvec(i_start:i_end) = prog_sig_t;
    nES = i_end-i_start+1;
    ES_zmat = repmat(ES_z',nES,1);
    sig_mat  = repmat(prog_sig_t,1,n_alpha);    
    ESmat(i_start:i_end,:) = par_mat(c,4) + sig_mat .* ES_zmat;
    if nargout > 2
        VaR_zmat = repmat(VaR_z',nES,1);
        VaRmat(i_start:i_end,:) = par_mat(c,4) + sig_mat .* VaR_zmat;
    end
end
if show_info, fprintf(' Done\n'); end
end
