function [ESmat,VaRmat,sigmat] = finrisk_dynESroll(alpha_in,method,pre_sample,sample,T_est,t_update)
% FINRISK_DYNESROLL performes a rolling Expected Shortfall (ES) estimation
%  
% Syntax: ESvec = FINRISK_DYNESROLL(alpha_in,method,pre_sample,sample,T_est,t_update)
%
% Inputs:
%   alpha_in    - significance level for ES calculation
%   method      - ES-estimation method; must be in {'emp','n','pot'}%
%   pre_sample  - observations used to calibrate the first VaR-models
%   sample      - observations corresponding to ES-forecasts and which are
%                 be used for later estimations 
%   T_est       - number of observations used in each estimation (default = 250)
%   t_update    - number of observations after which the estimate is updated (default = 1)  
%
% Outputs: ESvec - vector of ES values 
% 
% See also: finrisk_ESemp, finrisk_ESpar_data, finrisk_ESpot_data
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/08/20

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    sample = [];
end

if nargin < 5
    T_est = 250;
end

if nargin < 6
    t_update = 1;
end

%if size(alpha_in,1) > 1 || size(alpha_in,2) >1
%    error('not implemented yet');
%end
if size(alpha_in,2) > 1
    alpha_in = alpha_in';
end
nalpha = length(alpha_in);

t0 = length(pre_sample);
T_prog  = length(sample);

if T_prog < t_update
    T_prog = t_update; % only one forecast based on the presample only
end

l_all = [pre_sample;sample];
if t0 < T_est
    error('presample must contain at least T_est observations.');
end

% see calculations at the end of the file for index constructions
ESmat = zeros(T_prog,nalpha);
VaRmat = zeros(T_prog,nalpha);
sigmat = zeros(T_prog,nalpha);
fprintf('Estimating %s-ES #: ',method);
for t=0:t_update:T_prog-1
    if mod(t,100)==0
        fprintf('%d ',t);
    end
    ind_est_start = t0+(t+1)-T_est; % ex t=0: 1000 + 1 - 250 =  751;
    ind_est_end   = t0+(t+1)-1; % ex t=0: 1000 + 1 - 1   = 1000;
    l_est_t = l_all(ind_est_start:ind_est_end);
    i_start = t+1;
    i_end   = min(t+1+(t_update-1),T_prog);
    switch method
        case 'emp'
            ESnow = finrisk_ESemp(alpha_in,l_est_t);
            if nargout > 1
                VaRnow = finrisk_VaRemp(alpha_in,l_est_t);
                signow = std(l_est_t);
            end            
        case {'n','t','st','ghstd'}
            [ESnow,par_vec] = finrisk_ESpar_data(alpha_in,method,l_est_t);
            if nargout > 1
                VaRnow = finrisk_VaRpar(alpha_in,method,par_vec);
                if strcmp(method,'n')
                    signow = par_vec(2);
                elseif strcmp(method,'t')
                    signow = par_vec(3);
                elseif strcmp(method,'st') || strcmp(method,'ghstd')
                    signow = par_vec(4);
                end
            end
        case 'pot'
            [ESnow,VaRnow] = finrisk_ESpot_data(alpha_in,l_est_t);
            signow = std(l_est_t);
        otherwise
            error('method not implemented');
    end
    nES = i_end-i_start + 1;
    ESmat(i_start:i_end,:) = repmat(ESnow',nES,1);
    if nargout > 1
        VaRmat(i_start:i_end,:) = repmat(VaRnow',nES,1);
        sigmat(i_start:i_end,:) = repmat(signow,nES,nalpha);
    end
end
fprintf(' Done.\n');
end

    %t_update = 1, T_est = 250, t0= 1000 
    % t=0: ind_est_start = 1000+1-250 = 751
    %      ind_est_end  = 1000+1-1  = 1000
    %      i_start = 0+1 = 1
    %      i_end   = 0+1+1-1 = 1
    % t=1  ind_est_start = 1000+1+1- 250 = 752
    %      ind_est_end   = 1000+1+1-1    = 1001
    %      i_start       = 1+1 = 2
    %      i_end         = 1+1+1-1 = 2

    %t_update = 3, T_est = 250, t0=1000
    % t=0  ind_est_start wie oben 
    %      ind_est_end   wie oben
    %      i_start = 0+1 = 1 
    %      i_end   = 0+1+3-1 = 3
    % t=3  ind_est_start  1000+3+1-250 = 754
    %      ind_est_end    1000+3+1-1   =1003
    %      i_start = 3+1 = 4 
    %      i_end   = 3+1+3-1 = 6
