function [ESvec,sigvec,par_mat] = finrisk_dynESrs(alpha_in,K,pre_sample,sample,T_est,t_update,par_mat_in,nrep,show_info)
% FINRISK_DYNVARRS calculates a series of Value at Risk estimates using
% a series of regime switching models
%  
% Syntax: [VaRvec,par_mat] = finrisk_dynVaRrs(alpha_in,K,pre_sample,sample,...
%                                               T_est,t_update,par_mat_in,nrep,show_infp)
% Inputs:
%   alpha_in   - significance level/exceedance probability (vectors not
%                supported)
%   K          - number of regimes
%   pre_sample - observations used for estimation only
%   sample     - observations for which forecasts are calculated and which
%                might be used for later estimations 
%   T_est      - length of the (rolling) estimation window
%   t_update   - number of observations after which the forecast is updated
%   show_info  - 'true' if information should be displayed (standard='false')
%
% Outputs:
%   VaRvec  - vector with resulting VaR forecasts
%   sigvec  - vector of corresponding volatilities
%   par_mat - matrix of estimated parameters 
%
% see also: finrisk_est_garch, finrisk_volgarch_par
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/08/20

equal_dof = true;
stat = true;
use_par_before = true;

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    sample = [];
end

if nargin < 5
    T_est = 250;
end

if nargin < 6
    t_update = 1;
end

if nargin < 7 
    par_mat_in = [];
else
    par_mat = par_mat_in;
end

if nargin < 8
    nrep = 10;
end

if nargin < 8
    show_info = true;
end

%if size(alpha_in,1) > 1
%    error('not implemented yet');
%end

if size(alpha_in,2) > 1
    alpha_in = alpha_in';
end
n_alpha = length(alpha_in);

t0 = length(pre_sample);
T_prog  = length(sample);

if T_prog < t_update
    T_prog = t_update; % only one forecast based on the presample
end

l_all = [pre_sample;sample];
if t0 < T_est
    error('presample must contain at least T_est observations.');
end

ee = mle_est_opt('mix_mle',K);
ee.nrep = nrep;

oo = mle_out_opt();
if show_info
    oo.detail =1;
else
    oo.detail =0;
end

% see calculations at the end of the file for index constructions
ESvec = zeros(T_prog,n_alpha);
sigvec = zeros(T_prog,1);

if size(pre_sample,1)==size(sample,1) ...
        && size(pre_sample,1)==size(sample,1) ...
            && min(pre_sample == sample)
    in_sample = true;
else
    in_sample = false;
end

c=0;
if show_info, fprintf('Estimating RS-ES %s # ='); end
for t=0:t_update:T_prog-1
    c=c+1;
    %if mod(t,5)==0
        if show_info, fprintf(' %d ',c); end
    %end
    ind_est_start = t0+(t+1)-T_est; % Bsp t=0: 1000 + 1 - 250 =  751;
    ind_est_end   = t0+(t+1)-1; % Bsp t=0: 1000 + 1 - 1   = 1000;
    est_sample_t  = l_all(ind_est_start:ind_est_end);
    i_start = t+1;
    i_end   = t+1+(t_update-1);
    
    if t0+i_end > length(l_all)
        i_end = length(l_all) - t0;
    end
    sample_t = l_all(t0+i_start:t0+i_end);
    
    if use_par_before && c>1
        start_vec = par_mat(c-1,:);
    else
        start_vec = [];
    end
    
    % parameter estimation 
    if isempty(par_mat_in)
        [pi_c,Q,mu_c,sigma_c,nu_c] = rs_est('n',K,est_sample_t,ee,oo,start_vec,[],stat);
        par_mat(c,:) = rs_par2vec_stat('n',Q,mu_c,sigma_c,nu_c,equal_dof);
    else
        [Q,mu_c,sigma_c,nu_c] = rs_vec2par_stat('n',K,par_mat(c,:),equal_dof);
        pi_c = rs_pi_stat(Q);
    end
    
    if in_sample
        for k=1:n_alpha  
            [~,ESvec(:,k)] = rs_ES_L_pred(alpha_in(k),sample_t,'n',pi_c,Q,mu_c,sigma_c,nu_c);
            [~,xi_pred] = rs_filter(sample_t,'n',pi_c,Q,mu_c,sigma_c,nu_c);
            sigvec = sqrt(rs_stat(2,true,xi_pred,'n',mu_c,sigma_c,nu_c));
        end        
    else
        all_sample_now = [est_sample_t;sample_t];
        [~,xi_pred] = rs_filter(all_sample_now,'n',pi_c,Q,mu_c,sigma_c,nu_c);
        xi_pred_prog = xi_pred(:,length(est_sample_t)+1:end);
        for k=1:n_alpha  
            ESvec(i_start:i_end,k) = rs_ulambda(1-alpha_in(k),xi_pred_prog,'n',mu_c,sigma_c,nu_c);
        end
        sigvec(i_start:i_end) = sqrt(rs_stat(2,true,xi_pred_prog,'n',mu_c,sigma_c,nu_c));        
    end
end
if show_info, fprintf(' Done\n'); end
end
