function [VaRvec,sigvec,par_mat,zmats] = finrisk_dynVaRgarch(alpha_in,method,pre_sample,sample,T_est,t_update,inc_mean,show_info)
% FINRISK_DYNVARGARCH calculates a series of Value at Risk estimates using GARCH
% volatility forecasts 
%  
% Syntax: [VaRvec,sigvec,par_mat] = FINRISK_DYNVARGARCH(alpha_in,method,...
%             pre_sample,sample,T_est,t_update,inc_mean,show_info)
%
% Inputs:
%   alpha_in   - significance level/exceedance probability (vectors not
%                supported)
%   method     - VaR-estimation method; must be in {'emp','n','pot'}
%   pre_sample - observations used for estimation only
%   sample     - observations for which forecasts are calculated and which
%                might be used for later estimations 
%   T_est      - length of the (rolling) estimation window
%   t_update   - number of observations after which the forecast is updated
%   inc_mean   - include a mean constant in the model
%   show_info  - 'true' if information should be displayed (standard='false')
%
% Outputs:
%   VaRvec  - vector with resulting VaR forecasts
%   sigvec  - vector of corresponding volatilities
%   par_mat - matrix of estimated parameters 
%
% see also: finrisk_est_garch, finrisk_volgarch_par
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/08/20

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    sample = [];
end

if nargin < 5
    T_est = 250;
end

if nargin < 6
    t_update = 1;
end

if nargin < 7
    inc_mean = true;
end

if nargin < 8
    show_info = true;
end

%if size(alpha_in,1) > 1
%    error('not implemented yet');
%end

if size(alpha_in,2) > 1
    alpha_in = alpha_in';
end
n_alpha = length(alpha_in);

t0 = length(pre_sample);
T_prog  = length(sample);

if T_prog < t_update
    T_prog = t_update; % only one forecast based on the presample
end

if length(pre_sample)==length(sample) ... 
    && max(abs(pre_sample-sample))==0
   in_sample = true; 
else
   in_sample = false;
end


l_all = [pre_sample;sample];
if t0 < T_est
    error('presample must contain at least T_est observations.');
end

% see calculations at the end of the file for index constructions
VaRvec = zeros(T_prog,n_alpha);

c=0;
if show_info, fprintf('Estimating GARCH-VaR %s # =',method); end
for t=0:t_update:T_prog-1
    c=c+1;
    if mod(t,100)==0
        if show_info, fprintf(' %d ',c); end
    end
    ind_est_start = t0+(t+1)-T_est; % Bsp t=0: 1000 + 1 - 250 =  751;
    ind_est_end   = t0+(t+1)-1; % Bsp t=0: 1000 + 1 - 1   = 1000;
    est_sample_t  = l_all(ind_est_start:ind_est_end);
    i_start = t+1;
    i_end   = t+1+(t_update-1);
    
    if t0+i_end > length(l_all)
        i_end = length(l_all) - t0;
    end
    sample_t = l_all(t0+i_start:t0+i_end);
    
    % vola filter and forecast
    [par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4)] = finrisk_est_garch(est_sample_t,inc_mean);
    if in_sample
        prog_sig_t = finrisk_volgarch_par(est_sample_t,sample_t,par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4),2);
    else
        [prog_sig_t,pre_sig_t] = finrisk_volgarch_par(est_sample_t,sample_t,par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4));
    end
    
    %% neu -- use pre sample for its starting values 
    testneu_cond = true;
    if testneu_cond        
        pre_sig_t = finrisk_volgarch_par(est_sample_t,est_sample_t,par_mat(c,1),par_mat(c,2),par_mat(c,3),par_mat(c,4),2);
    end
    
    %disp(par_mat);
    
    % use filtered vola to estimate residuals
    z_sample_t = (est_sample_t-par_mat(c,4))./pre_sig_t;
    switch method
        case 'emp'
            VaR_z = finrisk_VaRemp(alpha_in,z_sample_t);
            res_par = [];
        case {'n','tstd','st','ghstd'}
            estls = false;            
            [VaR_z,res_par(c,:)] = finrisk_VaRpar_data(alpha_in,method,z_sample_t,[],estls);
            %VaR_z = norminv(1-alpha_in,0,1);
        case 'pot'
            [VaR_z,res_par(c,:)] = finrisk_VaRpot_data(alpha_in,z_sample_t);
        otherwise
            error('method not implemented');
    end
    zmats{c} = z_sample_t;
    sigvec(i_start:i_end) = prog_sig_t;
    nVaR = i_end-i_start+1; 
    VaR_zmat = repmat(VaR_z',nVaR,1);
    sig_mat  = repmat(prog_sig_t,1,n_alpha);
    VaRvec(i_start:i_end,:) = par_mat(c,4) + sig_mat .* VaR_zmat;
end
if ~isempty(res_par)
    par_mat = [par_mat res_par];
end
if show_info, fprintf(' Done\n'); end
end
