function VaRmat = finrisk_dynVaRroll(alpha_in,method,pre_sample,sample,T_est,t_update)
% FINRISK_DYNVARROLL performes rolling window VaR estimation (without time
% series modeling)
%  
% Syntax: VaRvec = FINRISK_DYNVARROLL(alpha_in,method,pre_sample,sample,T_est,t_update)
%
% Inputs:
%   alpha_in   - VaR significance level (exceedance probability)
%   method     - VaR-estimation method must be in {'emp','n','pot'}%
%   pre_sample - observations used to calibrate the first VaR-models
%   sample     - observations corresponding to VaR-forecasts and used
%                for later estimations 
%   T_est      - length of the observation window (default = 250)
%   t_update   - number of observations after which the forecast is updated
%                (default = 1)   
% 
% See also: finrisk_VaRemp, finrisk_VaRpar_data, finrisk_VaRpot_data
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/09/10

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    sample = [];
end

if nargin < 5
    T_est = 250;
end

if nargin < 6
    t_update = 1;
end

%if size(alpha_in,1) > 1 || size(alpha_in,2)>1
%    error('not implemented yet');
%end
nalpha = length(alpha_in);

if size(alpha_in,2)>1
    alpha_in = alpha_in';
end

t0 = length(pre_sample);
T_prog  = length(sample);

if T_prog < t_update
    T_prog = t_update; % only one forecast based on the presample
end

l_all = [pre_sample;sample];
if t0 < T_est
    error('presample must contain at least T_est observations.');
end

% see calculations at the end of the file for index constructions
VaRmat = zeros(T_prog,nalpha);
fprintf('Estimating %s-VaR #: ',method);
for t=0:t_update:T_prog-1
    if mod(t,100)==0
        fprintf('%d ',t);
    end
    ind_est_start = t0+(t+1)-T_est; % Bsp t=0: 1000 + 1 - 250 =  751;
    ind_est_end   = t0+(t+1)-1; % Bsp t=0: 1000 + 1 - 1   = 1000;
    l_est_t = l_all(ind_est_start:ind_est_end);
    i_start = t+1;
    i_end   = min(t+1+(t_update-1),T_prog);
    switch method
        case 'emp'
            VaRnow = finrisk_VaRemp(alpha_in,l_est_t);
        case {'n';'st';'t';'ghstd'}
            VaRnow = finrisk_VaRpar_data(alpha_in,method,l_est_t);            
        case 'pot'
            VaRnow = finrisk_VaRpot_data(alpha_in,l_est_t);
        otherwise
            error('method not implemented');
    end
    nVaR = i_end - i_start + 1;
    VaRmat(i_start:i_end,:) = repmat(VaRnow',nVaR,1);
end
fprintf(' Done.\n');
end
