function [sig_vec,sig_pre] = finrisk_volgarch_par(pre_sample,sample,alpha0,alpha1,beta1,mu,ver_sig0)
% FINRISK_VOLGARCH_PAR calculates GARCH(1,1) volatility with given 
%       parameters 
%
% Syntax:  [sig_prog,sig_pre] = FINRISK_VOLGARCH_PAR(pre_sample,sample,...
%                               alpha0,alpha1,beta1,mu,ver_sig0)
%
% Inputs:
%   pre_sample - pre sample observations
%   sample     - observations for which the GARCH filter is applied
%   alpha0     - GARCH parameter alpha_0
%   alpha1     - GARCH parameter alpha_1
%   beta1      - GARCH parameter beta_1
%   mu         - mean (standard: 'mu=0')
%   ver_sig0   - how to calculate first variance
%                '1' = unconditional model variance
%                '2' = empirical pre sample variance estimate
%                '3' = filtered variance estimate from the pre sample
%
% Outputs:
%   sig_vec    - estimated volatilities for the sample
%   sig_pre    - estimated volatilities for the pre sample
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/08/20

if nargin < 6
    mu = 0;
end

if nargin < 7
    if ~isempty(pre_sample)
        ver_sig0 = 3;
    else
        ver_sig0 = 1;
    end
end

T = length(sample);

l2 = (sample-mu).^2;

sig2vec   = zeros(T,1);

%    sig2_0 = var(presample); 
%    l2_0 = presample(end)^2;
%    sig2(1) = alpha0 + alpha1 * l2_0 + beta1 * sig2_0;
    
if isempty(pre_sample) && ~(ver_sig0 == 1)
    warning('no pre sample observations');
    ver_sig0 = 1;
end

switch ver_sig0
    case 1
        sig20   = alpha0/(1-alpha1-beta1);
        eps0    = sqrt(alpha0/(1-alpha1-beta1)); 
        sig_pre = [];        
%        sig2vec(1) = 
%        
    case 2
        sig20   = var(pre_sample);
        eps0    = std(pre_sample);
        sig_pre = [];
    case 3
        % recursive call to filter presample
        sig_pre = finrisk_volgarch_par([],pre_sample,alpha0,alpha1,beta1,mu,1);
        %sig2vec(1) = sig_pre(end)^2; -- bugfix 2015/08/20
        sig20  = sig_pre(end)^2;
        eps0 = pre_sample(end)-mu;
        
end
sig2vec(1) = alpha0 + alpha1 * eps0^2 + beta1 * sig20;    

for t=1:T-1
    sig2vec(t+1) = alpha0 + alpha1 * l2(t) + beta1 * sig2vec(t);
end

sig_vec = sqrt(sig2vec);

if nargout == 2 && isempty(pre_sample)
    error('presig only available if pre_sample is provided');
end
        
end