function [VaRl,VaRs] = finrisk_call_VaR(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_CALL_VaR calculates the VaR for call position (long/short) assuming 
%   the Black and Scholes model
%
% Syntax: [VaRl,VaRs] = FINRISK_CALL_VaR(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs:
%   alpha    - significance level
%   h        - risk horizon
%   mu       - drift parameter
%   s0       - current price of the underlying
%   x        - strike price
%   r        - interest rate
%   sigma    - volatility
%   tau      - time to maturity
%   incTheta - 'true': time decay (theta) for VaR-period is considered (standard).
%            - 'false': time decay not considered  
%
% Outputs: [VaRl,VaRs] - VaR for long and short position
%
% See also: finrisk_call_price, finrisk_gbm_price_par
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

    if nargin < 8
       error('not enough input arguments'); 
    end

    if nargin < 9
        incTheta = true;
    end
        
    [msh,vsh] = finrisk_gbm_price_par(h,s0,mu,sigma);
       
    % quantiles stock price
    q_alpha_sh   = logninv(alpha,msh,vsh);
    q_1malpha_sh = logninv(1-alpha,msh,vsh);
    
    c0 = finrisk_call_price(s0,x,r,sigma,tau);
    
    if incTheta
        tauh = tau - h;
    else
        tauh = tau;
    end
    
    % quantiles option price
    ch_long = finrisk_call_price(q_alpha_sh,x,r,sigma,tauh);
    ch_short = finrisk_call_price(q_1malpha_sh,x,r,sigma,tauh);
        
    VaRl = c0 - ch_long;
    VaRs = ch_short - c0;
end