function [VaRl,VaRs,lsim_l,lsim_s] = finrisk_call_VaR_sim(N,alpha_vec,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_CALL_VAR_SIM calculates the VaR for call position based on Monte
% Carlo simulation
%
% Syntax: [VaRl,VaRs] = FINRISK_CALL_VAR_SIM(N,alpha_vec,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs: 
%   N         - number of simulations
%   alpha_vec - vector of signifiance levels (exceedance probabilities)
%   h         - risk horizon
%   mu        - drift parameter
%   s0        - current price of the underlying
%   x         - strike price
%   r         - interest rate
%   sigma     - volatility
%   tau       - time to maturity
%   incTheta  - if 'true' then time decay (theta) for VaR-period not 
%               considered. If 'false' then time decay 
%               considered.
%
% Outputs:
%   [VaRl,VaRs]     - Monte-Carlo-VaR for long and short position
%   [lsim_l,lsim_s] - simulated losses for long and short position
%
% See also: finrisk_gbm_price_rnd, finrisk_call_price, finrisk_VaRemp
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

    if nargin < 9 
       error('not enough input arguments');
    end

    if nargin < 10 
        incTheta = true;
    end

    Shsim = finrisk_gbm_price_rnd(N,h,s0,mu,sigma);
    Chsim = zeros(N,1);
    c0 = finrisk_call_price(s0,x,r,sigma,tau);
    
    if incTheta
        tauh = tau - h;
    else
        tauh = tau;
    end
    
    Chsim(:,1) = finrisk_call_price(Shsim,x,r,sigma,tauh);
    
    lsim_l  = -(Chsim - c0);
    lsim_s = -(c0 - Chsim);
    
    VaRl = finrisk_VaRemp(alpha_vec,lsim_l);
    VaRs = finrisk_VaRemp(alpha_vec,lsim_s);
end