function Lp_vec = finrisk_cprnd_hfak(Nsim,PD,n,rho,E,typ_l,typ_am,xpar)
% FINRISK_CPRND_HFAK simulation of losses from a homogeneous factor model 
%   with correlated defaults 
%
% Syntax: Lp_vec = FINRISK_CPRND_HFAK(Nsim,PD,n,rho,E,typ_l,typ_am,xpar)
%
% Inputs:
%   Nsim     - number of simulations
%   PD       - default probability
%   n        - portfolio size
%   rho      - factor sensitivity/default correlation
%   E        - credit exposure
%   typ_l    - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%              barL_p,n
%   typ_am   - distributional assumption for the asset model 
%              'mvn1', 'mvn2', 'mvn3' different implementations of the
%              standard factor model based on a multivariate normal
%              distribution (use mvn3)
%              'tcop1', 'tcop2' different implementations of the factor
%              model based on a t copula (use tcop2)
%   xpar     - degrees of freedom parameter for t copula models
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    

    if nargin < 4
        error('not enough input arguments');
    end

    if nargin < 5
        E = 1;
    end
    
    if nargin < 6
        typ_l = 1;
    end
    
    if nargin < 7
        typ_am = 'mvn3';
    end
    
    if max(strcmp(typ_am,{'mvn1','mvn2','tcop1'}))
        muY  = zeros(n,1);
        SigY = rho* ones(n,n);
        for i=1:n
            SigY(i,i) = 1;
        end
    end

 
     Nsim_max = 10^7/n;
%    if n < 10^4
%       Nsim_max = 10^4;
%    else
%       Nsim_max = 10^3;
%    end
   
   if Nsim > Nsim_max
      Nruns = ceil(Nsim/Nsim_max);          
   else
      Nruns = 1;
   end
    
    Dpvec = zeros(Nsim,1);
    for k=1:Nruns
        if k==Nruns
           Nsimk = Nsim - (k-1)*Nsim_max;
        else
           Nsimk = Nsim_max;
        end
        
        switch typ_am
            case 'mvn1'
                warning('this implementation is slow. use mvn3 instead.');
                H = norminv(PD,0,1);
                Ymat   = (mvnrnd(muY,SigY,Nsimk))';
                Dimat  = Ymat < H;
            case 'mvn2'
                warning('this implementation is slow. use mvn3 instead.');
                Umat   = (copularnd('Gaussian',SigY,Nsimk))';
                Dimat  = Umat < PD;        
            case 'mvn3'
                % 5.2.18 a)
                H = norminv(PD,0,1);
                %Umat   = (mvnrnd(muY,eye(n),Nsim))';
                Umat   = normrnd(0,1,n,Nsimk);
                Fvec   = normrnd(0,1,1,Nsimk);
                Fmat   = repmat(Fvec,n,1);
                Ymat   = sqrt(rho) .* Fmat + sqrt(1-rho) .* Umat;
                Dimat  = Ymat < H;
            case 'tcop1'
                warning('this implementation is slow. use tcop2 instead.');                
                % see commments on 5.2.44
                Umat   = (copularnd('t',SigY,xpar,Nsimk))';
                Dimat  = Umat < PD;
            case 'tcop2'
                % see 5.2.44
                H      = tinv(PD,xpar);
                %Umat   = (mvnrnd(muY,eye(n),Nsim))';
                Umat   = normrnd(0,1,n,Nsimk);
                Fvec   = normrnd(0,1,1,Nsimk);
                Fmat   = repmat(Fvec,n,1);
                Vmat   = sqrt(rho) .* Fmat + sqrt(1-rho) .* Umat;
                Wvec   = chi2rnd(xpar,1,Nsimk);
                fakvec = sqrt(xpar./Wvec);
                fakmat = repmat(fakvec,n,1);
                Dimat  = fakmat .* Vmat < H;
            otherwise
                error('unkown model');
        end
        if k<Nruns
           istart = (k-1)*Nsim_max + 1;
           iend   =  k   *Nsim_max;
        else
           istart = (Nruns-1)*Nsim_max + 1;
           iend   = Nsim;
        end
        Dpvec(istart:iend) =  sum(Dimat);
    end
    
    Lp_vec = finrisk_cp_transDx(Dpvec,n,E,typ_l);
end