function [p_vec,mu_vec,sigma_vec,gmd] = finrisk_est_mix(K,dat,NReplications)
% FINRISK_EST_MIX uses gmdistribution.fit for the estimation of normal
% mixture parameters
%  
% Syntax: 
%   [p_vec,mu_vec,sigma_vec] = FINRISK_EST_MIX(K,dat)
%   [p_vec,mu_vec,sigma_vec] = FINRISK_EST_MIX(K,dat,NReplications)
%   [p_vec,mu_vec,sigma_vec,gmd] = FINRISK_EST_MIX(...)
%
% Inputs:
%   K             -  number of components 
%   dat           -  vector of input dat
%   NReplications -  number of times to repeat estimation algorithm with
%                    different start values (standard: 200)
%
% Outputs:
%   p_vec     - vector of weights
%   mu_vec    - vector of means
%   sigma_vec - vector of standard deviations
%   gmd       - total output of 'gmdistribution.fit'
%
% See also: finrisk_VaRmix, finrisk_VaRmix_dat, gmdistribution
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3 || isempty(NReplications)
    NReplications = 200; %K * 100
end

if size(dat,2) > 1
    error('use mixnmv_est_mat()')
end

optset = statset('gmdistribution');
optset.MaxIter  = 1000;
optset.TolFun = 1e-8;

if NReplications < 20
    warning('Increase number of restarts of the EM-algorithm to obtain more reliable results');
end

gmd = gmdistribution.fit(dat,K,'Replicates',NReplications,'Options',optset);
if ~gmd.Converged
    warning('Estimation has not converged.');
end
p_vec = gmd.PComponents;
mu_vec(1,:) = gmd.mu;
sigma_vec(1,:) = sqrt(gmd.Sigma(1,1,:));

end