function [mu,sig_std,nu,sig_par] = finrisk_est_t(dat,method,estls)
% FINRISK_EST_T estimates the three-parameter t-distribution
%   (L=mu+sigma*T where T follows standard t-distribution)
%  
% Syntax: 
%   [mu,sig_std,nu,sig_par] = FINRISK_EST_T(dat,method) 
%   [mu,sig_std,nu,sig_par] = FINRISK_EST_T(dat) 
%
% Inputs:
%   dat    - vector with input-data
%   method - estimation-method: 'mom' for estimation based on 
%            moments of the distribution, 'mle' for maximum 
%            likelihood estimation (standard: 'mom')
%
% Outputs:
%   mu      - estimated location parameter 
%   sig_std - estimated standard deviation
%   nu      - estimated degrees of freedom
%   sig_par - estimated standard deviation for L
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

    if nargin < 3
        estls = true;
    end

    if ~estls
        error('not implemented');
    end
    

    if nargin < 2 || isempty(method)
        if ~estls
            method = '2s';
        else               
            method = 'mom';
        end
    end
    

    if estls && strcmp(method,'mle')
        warning('using 2s instead of mle. check settings.');
    end
        
    switch method
        case 'mom'
            if estls
                mu = mean(dat);
                sig_std  = std(dat);
            else
                mu = 0;
                sig_std = 1;
            end
            xkurt = kurtosis(dat)-3;
            nu = 6/(xkurt)+4;       
            sig_par = sqrt((nu-2)/nu) * sig_std;
            if nu < 0 
                warning('moment based estimation failed. Running MLE.');
                [mu,sig_std,nu,sig_par] = finrisk_est_t(dat,'mle');
            end
        case 'mle'
            objdist = fitdist(dat,'tlocationscale');
            %par = mle(dat,'distribution','t');
            mu = objdist.mu;
            sig_par = objdist.sigma;
            nu = objdist.nu;
            %mu = par(1);
            %sig_par = par(2);
            %nu = par(3);
                sig_std = sqrt(nu/(nu-2)) * sig_par;
        case '2s'
            if estls
                mu = mean(dat);
                sig_std = std(dat);            
            else
                mu= 0;
                sig_std = 1;
            end
            zdat = (dat - mu)./sig_std;
            nu = t_est(zdat,1,false);
            sig_par = sqrt((nu-2)/nu) * sig_std;
        otherwise
            error('method not implemented');
    end
end